@@ -295,6 +295,7 @@ setClass("CovControlMMest", representation(bdp="numeric",
 setClass("Pca", representation(call = "language",
                               center = "vector",
                               scale = "Uvector",
+                              rank = "numeric",
                               loadings = "matrix",
                               eigenvalues = "vector",
                               scores = "matrix",
@@ -306,6 +307,8 @@ setClass("Pca", representation(call = "language",
                               crit.pca.distances = "numeric",
                               flag = "Uvector",
                               n.obs = "numeric",
+                              eig0 = "vector",
+                              totvar0 = "numeric",
                               "VIRTUAL"))
 
 setClass("SummaryPca", representation(pcaobj = "Pca",
@@ -317,7 +320,9 @@ setClass("PcaRobust", representation("VIRTUAL"),
                     contains="Pca")
 
 setClass("PcaHubert", representation(alpha = "numeric",
-                                  quan = "numeric"),
+                                     quan = "numeric",
+                                     skew = "logical",
+                                     ao = "Uvector"),
                     contains="PcaRobust")
 setClass("PcaLocantore", representation(),
                     contains="PcaRobust")
